
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    print qq{1..0 # SKIP these tests are for testing by the author\n};
    exit
  }
}

use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.19

use Test::More 0.88;
use Test::EOL;

my @files = (
    'lib/Search/Elasticsearch.pm',
    'lib/Search/Elasticsearch/Client/6_0.pm',
    'lib/Search/Elasticsearch/Client/6_0/Bulk.pm',
    'lib/Search/Elasticsearch/Client/6_0/Direct.pm',
    'lib/Search/Elasticsearch/Client/6_0/Direct/Cat.pm',
    'lib/Search/Elasticsearch/Client/6_0/Direct/Cluster.pm',
    'lib/Search/Elasticsearch/Client/6_0/Direct/Indices.pm',
    'lib/Search/Elasticsearch/Client/6_0/Direct/Ingest.pm',
    'lib/Search/Elasticsearch/Client/6_0/Direct/Nodes.pm',
    'lib/Search/Elasticsearch/Client/6_0/Direct/Snapshot.pm',
    'lib/Search/Elasticsearch/Client/6_0/Direct/Tasks.pm',
    'lib/Search/Elasticsearch/Client/6_0/Role/API.pm',
    'lib/Search/Elasticsearch/Client/6_0/Role/Bulk.pm',
    'lib/Search/Elasticsearch/Client/6_0/Role/Scroll.pm',
    'lib/Search/Elasticsearch/Client/6_0/Scroll.pm',
    'lib/Search/Elasticsearch/Client/6_0/TestServer.pm',
    'lib/Search/Elasticsearch/Cxn/Factory.pm',
    'lib/Search/Elasticsearch/Cxn/HTTPTiny.pm',
    'lib/Search/Elasticsearch/Cxn/Hijk.pm',
    'lib/Search/Elasticsearch/Cxn/LWP.pm',
    'lib/Search/Elasticsearch/CxnPool/Sniff.pm',
    'lib/Search/Elasticsearch/CxnPool/Static.pm',
    'lib/Search/Elasticsearch/CxnPool/Static/NoPing.pm',
    'lib/Search/Elasticsearch/Error.pm',
    'lib/Search/Elasticsearch/Logger/LogAny.pm',
    'lib/Search/Elasticsearch/Role/API.pm',
    'lib/Search/Elasticsearch/Role/Client.pm',
    'lib/Search/Elasticsearch/Role/Client/Direct.pm',
    'lib/Search/Elasticsearch/Role/Cxn.pm',
    'lib/Search/Elasticsearch/Role/CxnPool.pm',
    'lib/Search/Elasticsearch/Role/CxnPool/Sniff.pm',
    'lib/Search/Elasticsearch/Role/CxnPool/Static.pm',
    'lib/Search/Elasticsearch/Role/CxnPool/Static/NoPing.pm',
    'lib/Search/Elasticsearch/Role/Is_Sync.pm',
    'lib/Search/Elasticsearch/Role/Logger.pm',
    'lib/Search/Elasticsearch/Role/Serializer.pm',
    'lib/Search/Elasticsearch/Role/Serializer/JSON.pm',
    'lib/Search/Elasticsearch/Role/Transport.pm',
    'lib/Search/Elasticsearch/Serializer/JSON.pm',
    'lib/Search/Elasticsearch/Serializer/JSON/Cpanel.pm',
    'lib/Search/Elasticsearch/Serializer/JSON/PP.pm',
    'lib/Search/Elasticsearch/Serializer/JSON/XS.pm',
    'lib/Search/Elasticsearch/TestServer.pm',
    'lib/Search/Elasticsearch/Transport.pm',
    'lib/Search/Elasticsearch/Util.pm',
    't/10_Basic/10_load.t',
    't/20_Serializer/10_load_cpanel.t',
    't/20_Serializer/11_load_xs.t',
    't/20_Serializer/12_load_pp.t',
    't/20_Serializer/13_preload_cpanel.t',
    't/20_Serializer/14_preload_xs.t',
    't/20_Serializer/20_xs_encode_decode.t',
    't/20_Serializer/21_xs_encode_bulk.t',
    't/20_Serializer/22_xs_encode_pretty.t',
    't/20_Serializer/30_cpanel_encode_decode.t',
    't/20_Serializer/31_cpanel_encode_bulk.t',
    't/20_Serializer/32_cpanel_encode_pretty.t',
    't/20_Serializer/40_pp_encode_decode.t',
    't/20_Serializer/41_pp_encode_bulk.t',
    't/20_Serializer/42_pp_encode_pretty.t',
    't/20_Serializer/encode_bulk.pl',
    't/20_Serializer/encode_decode.pl',
    't/20_Serializer/encode_pretty.pl',
    't/30_Logger/10_explicit.t',
    't/30_Logger/20_implicit.t',
    't/30_Logger/30_log_methods.t',
    't/30_Logger/40_trace_request.t',
    't/30_Logger/50_trace_response.t',
    't/30_Logger/60_trace_error.t',
    't/30_Logger/70_trace_comment.t',
    't/30_Logger/80_deprecation_methods.t',
    't/30_Logger/90_error_json.t',
    't/40_Transport/10_tidy_request.t',
    't/40_Transport/20_send_body_as.t',
    't/40_Transport/30_perform_request.t',
    't/50_Cxn_Pool/10_static_normal.t',
    't/50_Cxn_Pool/11_static_node_missing.t',
    't/50_Cxn_Pool/12_static_node_fails.t',
    't/50_Cxn_Pool/13_static_node_timesout.t',
    't/50_Cxn_Pool/14_static_both_nodes_timeout.t',
    't/50_Cxn_Pool/15_static_both_nodes_fail.t',
    't/50_Cxn_Pool/16_static_nodes_starting.t',
    't/50_Cxn_Pool/17_static_runaway_nodes.t',
    't/50_Cxn_Pool/30_sniff_normal.t',
    't/50_Cxn_Pool/31_sniff_new_nodes.t',
    't/50_Cxn_Pool/32_sniff_node_fails.t',
    't/50_Cxn_Pool/33_sniff_both_nodes_fail.t',
    't/50_Cxn_Pool/34_sniff_node_timeout.t',
    't/50_Cxn_Pool/35_sniff_both_nodes_timeout.t',
    't/50_Cxn_Pool/36_sniff_nodes_starting.t',
    't/50_Cxn_Pool/37_sniff_runaway_nodes.t',
    't/50_Cxn_Pool/38_bad_sniff.t',
    't/50_Cxn_Pool/39_sniff_max_content.t',
    't/50_Cxn_Pool/40_sniff_extract_host.t',
    't/50_Cxn_Pool/50_noping_normal.t',
    't/50_Cxn_Pool/51_noping_node_fails.t',
    't/50_Cxn_Pool/52_noping_node_timesout.t',
    't/50_Cxn_Pool/53_noping_all_nodes_fail.t',
    't/50_Cxn_Pool/54_noping_nodes_starting.t',
    't/50_Cxn_Pool/55_noping_runaway_nodes.t',
    't/50_Cxn_Pool/56_max_retries.t',
    't/60_Cxn/10_basic.t',
    't/60_Cxn/20_process_response.t',
    't/60_Cxn/30_http.t',
    't/95_TestServer/00_test_server.t',
    't/95_TestServer/10_test_server_fork.t',
    't/Client_6_0/00_print_version.t',
    't/Client_6_0/10_live.t',
    't/Client_6_0/15_conflict.t',
    't/Client_6_0/20_fork_httptiny.t',
    't/Client_6_0/21_fork_lwp.t',
    't/Client_6_0/22_fork_hijk.t',
    't/Client_6_0/30_bulk_add_action.t',
    't/Client_6_0/31_bulk_helpers.t',
    't/Client_6_0/32_bulk_flush.t',
    't/Client_6_0/33_bulk_errors.t',
    't/Client_6_0/34_bulk_cxn_errors.t',
    't/Client_6_0/40_scroll.t',
    't/Client_6_0/60_auth_httptiny.t',
    't/Client_6_0/61_auth_lwp.t',
    't/author-eol.t',
    't/author-no-tabs.t',
    't/author-pod-syntax.t',
    't/lib/LogCallback.pl',
    't/lib/MockCxn.pm',
    't/lib/bad_cacert.pem',
    't/lib/default_cxn.pl',
    't/lib/es_sync.pl',
    't/lib/es_sync_auth.pl',
    't/lib/es_sync_fork.pl',
    't/lib/index_test_data.pl'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
